@@ -5,6 +5,7 @@ import json
 import logging
 import time
 
+import requests.exceptions
 import six
 from six.moves.urllib import parse as urlparse
 
@@ -172,19 +173,19 @@ class Status(_TAXIIEndpoint):
             msg = "No 'pending_count' in Status for request '{}'"
             raise ValidationError(msg.format(self.url))
 
-        if len(self.successes) != self.success_count:
+        if self.successes and len(self.successes) != self.success_count:
             msg = "Found successes={}, but success_count={} in status '{}'"
             raise ValidationError(msg.format(self.successes,
                                              self.success_count,
                                              self.id))
 
-        if len(self.pendings) != self.pending_count:
+        if self.pendings and len(self.pendings) != self.pending_count:
             msg = "Found pendings={}, but pending_count={} in status '{}'"
             raise ValidationError(msg.format(self.pendings,
                                              self.pending_count,
                                              self.id))
 
-        if len(self.failures) != self.failure_count:
+        if self.failures and len(self.failures) != self.failure_count:
             msg = "Found failures={}, but failure_count={} in status '{}'"
             raise ValidationError(msg.format(self.failures,
                                              self.failure_count,
@@ -377,7 +378,17 @@ class Collection(_TAXIIEndpoint):
         if per_request > 0:
             headers["Range"] = "items={}-{}".format(start, (start + per_request) - 1)
 
-        return self._conn.get(self.objects_url, headers=headers, params=query_params)
+        try:
+            response = self._conn.get(self.objects_url, headers=headers, params=query_params)
+        except requests.exceptions.HTTPError as e:
+            if per_request > 0:
+                # This is believed to be an error in TAXII 2.0
+                # http://docs.oasis-open.org/cti/taxii/v2.0/cs01/taxii-v2.0-cs01.html#_Toc496542716
+                headers["Range"] = "items {}-{}".format(start, (start + per_request) - 1)
+                response = self._conn.get(self.objects_url, headers=headers, params=query_params)
+            else:
+                raise e
+        return response
 
     def get_object(self, obj_id, version=None, accept=MEDIA_TYPE_STIX_V20):
         """Implement the ``Get an Object`` endpoint (section 5.5)"""
@@ -475,7 +486,17 @@ class Collection(_TAXIIEndpoint):
         if per_request > 0:
             headers["Range"] = "items={}-{}".format(start, (start + per_request) - 1)
 
-        return self._conn.get(self.manifest_url, headers=headers, params=query_params)
+        try:
+            response = self._conn.get(self.manifest_url, headers=headers, params=query_params)
+        except requests.exceptions.HTTPError as e:
+            if per_request > 0:
+                # This is believed to be an error in TAXII 2.0
+                # http://docs.oasis-open.org/cti/taxii/v2.0/cs01/taxii-v2.0-cs01.html#_Toc496542716
+                headers["Range"] = "items {}-{}".format(start, (start + per_request) - 1)
+                response = self._conn.get(self.manifest_url, headers=headers, params=query_params)
+            else:
+                raise e
+        return response
 
 
 class ApiRoot(_TAXIIEndpoint):
